@@ -636,16 +636,6 @@ class Cluster(AbcCluster):
 
         pool = await self._pooler.ensure_pool(node_addr)
 
-        # pool_size = pool.size
-        # if pool_size >= pool.maxsize and pool.freesize == 0:
-        #     logger.warning(
-        #         "ConnectionPool to %s size limit reached (minsize:%s, maxsize:%s, current:%s])",
-        #         node_addr,
-        #         pool.minsize,
-        #         pool.maxsize,
-        #         pool_size,
-        #     )
-
         if props.asking:
             logger.info("Send ASKING to %s for command %r", node_addr, ctx.cmd_name)
 
@@ -760,7 +750,7 @@ class Cluster(AbcCluster):
         if opts is None:
             opts = {}
 
-        default_opts = dict(
+        default_opts: Dict[str, Any] = dict(
             pool_cls=self._pool_cls,
             password=self._password,
             encoding=self._encoding,
