@@ -176,6 +176,7 @@ async def test_create_pool(mocker):
         minsize=5,
         maxsize=15,
         create_connection_timeout=1.2,
+        ssl=None,
     )
 
 
@@ -212,6 +213,7 @@ async def test_create_pool_by_addr(mocker):
         minsize=5,
         maxsize=42,
         create_connection_timeout=1.2,
+        ssl=None,
     )
 
 
@@ -415,7 +417,7 @@ async def test_execute__success_several_problem_retry(mocker):
 
     assert mocked_manager.get_state.call_count == 10
     assert mocked_pooler.ensure_pool.call_count == 10
-    assert mocked_manager.require_reload_state.call_count == 8
+    assert mocked_manager.require_reload_state.call_count == 7
     assert result == ("result", 10)
 
     ensure_pool_calls = mocked_pooler.ensure_pool.call_args_list
@@ -444,7 +446,7 @@ async def test_execute__success_several_problem_retry(mocker):
     state.slot_master.assert_called_once_with(12539)
     assert state.random_slot_replica.call_count == 1
     assert state.random_slot_replica.call_args == mock.call(12539)
-    assert state.random_node.call_count == 5
+    assert state.random_node.call_count == 4
     assert mocked_execute_retry_slowdown.call_count == 9
 
     asking_calls = [c for c in conn.execute.call_args_list if c == mock.call(b"ASKING")]
@@ -584,13 +586,13 @@ async def test_execute__retriable_error_in_unexpected_call(mocker):
         (OSError(), Address("random_replica", 6379), 1),
         (ConnectTimeoutError(object()), Address("random_replica", 6379), 1),
         (ClusterDownError("CLUSTERDOWN clusterdown"), Address("random", 6379), 1),
-        (TryAgainError("TRYAGAIN tryagain"), Address("random", 6379), 1),
+        (TryAgainError("TRYAGAIN tryagain"), Address("master", 6379), 0),
         (MovedError("MOVED 12539 1.2.3.4:1000"), Address("1.2.3.4", 1000), 1),
         (AskError("ASK 12539 1.2.3.4:1000"), Address("1.2.3.4", 1000), 0),
         (LoadingError("LOADING loading"), Address("random", 6379), 1),
         (ProtocolError(), Address("random", 6379), 1),
         (ConnectionClosedError(), Address("random_replica", 6379), 1),
-        (ConnectionForcedCloseError(), Address("random_replica", 6379), 1),
+        (ConnectionForcedCloseError(), Address("random_replica", 6379), 0),
         (PoolClosedError(), Address("random_replica", 6379), 1),
     ],
 )
